function [Acc, Aff, Acf, Afc] = FCN_BC(A, DOFc)
%
% Funkcia sluzi zavedenie okrajovych podmienok do globalnej matice tuhosti, 
% resp. hmotnosti neuvazbeneho telesa, resp. vektora vonkajsich sil.
% Program vstupnu maticu/vektor A rozdeli za riadkom/stlpcom DOFc na 
% submatice/subvektory Acc, Aff, Acf, Afc resp. Acc, Aff ak A je vektor.
%
% Inputs:
%
%   A   -   Matica/vektor, ktoru chceme rozdelit
%   Dofc-   Pocet uvazbenych stupnov volnosti
%
% Outputs:
%
%   Acc  -   Submatica/subvektor, vzniknuta rozdelenim matice/vektora A
%   Aff  -   Submatica/subvektor, vzniknuta rozdelenim matice/vektora A
%   Acf  -   Submatica/subvektor, vzniknuta rozdelenim matice/vektora A
%   Afc  -   Submatica/subvektor, vzniknuta rozdelenim matice/vektora A
%
% Example:
%
%   [Kcc, Kff, Kcf, Kfc] = FCN_BC(K, 3)
%
% Urcene pre vyuku predmetu MKP v dynamike struktur I, II
% Autor:    Vedelin Hok

n = length(A);
% A je vektor +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
if nargout == 2 
    Acc = A(1:DOFc); 
    Aff = A(DOFc+1:n);

% A je stvorcova matica +++++++++++++++++++++++++++++++++++++++++++++++++++   
else           
    Acc = A(1:DOFc, 1:DOFc);
    Acf = A(1:DOFc, DOFc+1:n);
    Afc = A(DOFc+1:n, 1:DOFc);
    Aff = A(DOFc+1:n, DOFc+1:n);
end

